
import React from 'react';
import { motion } from 'framer-motion';
import { Target, Eye, Leaf, Users } from 'lucide-react';

const FeatureCard = ({ icon, title, description }) => {
  const IconComponent = icon;
  return (
    <motion.div 
      className="bg-white/10 backdrop-blur-md p-6 rounded-xl shadow-lg flex items-start space-x-4 border border-white/20"
      initial={{ opacity: 0, x: -30 }}
      whileInView={{ opacity: 1, x: 0 }}
      viewport={{ once: true }}
      transition={{ duration: 0.5 }}
    >
      <div className="p-3 bg-yellow-400 rounded-full text-purple-700">
        <IconComponent size={28} />
      </div>
      <div>
        <h3 className="text-xl font-semibold text-white mb-2">{title}</h3>
        <p className="text-white/80 leading-relaxed">{description}</p>
      </div>
    </motion.div>
  );
};

const AboutSection = () => {
  return (
    <section id="about" className="py-16 md:py-24 bg-gradient-to-b from-orange-600 to-red-700">
      <div className="container mx-auto px-4">
        <div className="grid md:grid-cols-2 gap-12 items-center">
          <motion.div
            initial={{ opacity: 0, x: -50 }}
            whileInView={{ opacity: 1, x: 0 }}
            viewport={{ once: true }}
            transition={{ duration: 0.7 }}
          >
            <h2 className="text-4xl md:text-5xl font-bold text-yellow-400 mb-6">Biz Kimiz?</h2>
            <p className="text-white/90 text-lg mb-6 leading-relaxed">
              PedalReklam olarak, markaların mesajlarını yenilikçi ve çevre dostu bir şekilde hedef kitlelerine ulaştırmalarına yardımcı oluyoruz. Bisikletli reklamcılık alanında uzmanlaşmış dinamik bir ekibiz ve şehirlerin enerjisini markanızın enerjisiyle birleştiriyoruz.
            </p>
            <p className="text-white/90 text-lg mb-8 leading-relaxed">
              Amacımız, sadece dikkat çekici değil, aynı zamanda akılda kalıcı ve pozitif etki yaratan kampanyalar tasarlamaktır. Sürdürülebilir bir gelecek için pedallarken, markanızın da bu yolculukta parlamasını sağlıyoruz.
            </p>
            <div className="w-full h-80 md:h-96 rounded-xl overflow-hidden shadow-xl border-4 border-yellow-400/50">
              <img  class="w-full h-full object-cover" alt="Team of cyclists preparing for an advertising campaign" src="https://images.unsplash.com/photo-1470313131924-5aceea1d1bad" />
            </div>
          </motion.div>

          <div className="space-y-8">
            <FeatureCard 
              icon={Target}
              title="Hedef Odaklı"
              description="Kampanyalarınızı doğru kitleye, doğru zamanda ve doğru yerde ulaştırıyoruz."
            />
            <FeatureCard 
              icon={Eye}
              title="Yüksek Görünürlük"
              description="Hareketli reklamlarımızla şehrin her köşesinde maksimum görünürlük sağlıyoruz."
            />
            <FeatureCard 
              icon={Leaf}
              title="Çevre Dostu"
              description="Sıfır karbon emisyonu ile sürdürülebilir ve yeşil bir reklam çözümü sunuyoruz."
            />
             <FeatureCard 
              icon={Users}
              title="Profesyonel Ekip"
              description="Deneyimli bisikletçilerimiz ve kampanya yöneticilerimizle projenizi hayata geçiriyoruz."
            />
          </div>
        </div>
      </div>
    </section>
  );
};

export default AboutSection;
